AFRL labeling Object Info (sarpy.annotation.afrl_elements.ObjectInfo)
=====================================================================

.. automodule:: sarpy.annotation.afrl_elements.ObjectInfo
    :members:
    :show-inheritance:
    :inherited-members:
